@@ -154,7 +154,11 @@ public class FormatData_cv extends ListResourceBundle {
             "3-\u043c\u04d7\u0448 \u043a\u0432.",
             "4-\u043c\u04d7\u0448 \u043a\u0432.",
         };
-        final String[] metaValue_Eras = new String[] {
+        final String[] metaValue_java_time_long_Eras = new String[] {
+            "\u0425\u0440\u0438\u0441\u0442\u043e\u0441 \u04ab\u0443\u0440\u0430\u043b\u043d\u04d1 \u043a\u0443\u043d\u0447\u0447\u0435\u043d",
+            "\u0425\u0440\u0438\u0441\u0442\u043e\u0441 \u04ab\u0443\u0440\u0430\u043b\u043d\u04d1 \u043a\u0443\u043d\u0440\u0430\u043d",
+        };
+        final String[] metaValue_java_time_Eras = new String[] {
             "\u043f. \u044d.",
             "\u0445. \u044d.",
         };
@@ -207,6 +211,20 @@ public class FormatData_cv extends ListResourceBundle {
             "dd.MM.y GGGG",
         };
         final String metaValue_calendarname_gregorian = "\u0433\u0440\u0435\u0433\u043e\u0440\u0438\u0430\u043d \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u04d7";
+        final String[] metaValue_ListPatterns_standard = new String[] {
+            "",
+            "",
+            "{0} \u0442\u0430\u0442\u0430 {1}",
+            "{0} \u0442\u0430\u0442\u0430 {1}",
+            "",
+        };
+        final String[] metaValue_ListPatterns_or = new String[] {
+            "",
+            "",
+            "{0} \u0435 {1}",
+            "{0} \u0435 {1}",
+            "",
+        };
         final Object[][] data = new Object[][] {
             { "generic.DayNames", metaValue_generic_DayNames },
             { "generic.DayAbbreviations", metaValue_generic_DayAbbreviations },
@@ -275,14 +293,12 @@ public class FormatData_cv extends ListResourceBundle {
             { "standalone.QuarterNames", metaValue_generic_QuarterNames },
             { "QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "standalone.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "long.Eras",
-                new String[] {
-                    "\u0425\u0440\u0438\u0441\u0442\u043e\u0441 \u04ab\u0443\u0440\u0430\u043b\u043d\u04d1 \u043a\u0443\u043d\u0447\u0447\u0435\u043d",
-                    "\u0425\u0440\u0438\u0441\u0442\u043e\u0441 \u04ab\u0443\u0440\u0430\u043b\u043d\u04d1 \u043a\u0443\u043d\u0440\u0430\u043d",
-                }
-            },
-            { "Eras", metaValue_Eras },
-            { "narrow.Eras", metaValue_Eras },
+            { "java.time.long.Eras", metaValue_java_time_long_Eras },
+            { "long.Eras", metaValue_java_time_long_Eras },
+            { "java.time.Eras", metaValue_java_time_Eras },
+            { "Eras", metaValue_java_time_Eras },
+            { "java.time.narrow.Eras", metaValue_java_time_Eras },
+            { "narrow.Eras", metaValue_java_time_Eras },
             { "field.era", "\u044d\u0440\u0430" },
             { "field.year", "\u04ab\u0443\u043b" },
             { "field.month", "\u0443\u0439\u04d1\u0445" },
@@ -337,7 +353,6 @@ public class FormatData_cv extends ListResourceBundle {
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.DayNames", metaValue_generic_DayNames },
             { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
             { "buddhist.QuarterNames", metaValue_generic_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
@@ -375,7 +390,6 @@ public class FormatData_cv extends ListResourceBundle {
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "japanese.DayNames", metaValue_generic_DayNames },
             { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
             { "japanese.QuarterNames", metaValue_generic_QuarterNames },
             { "japanese.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
@@ -449,7 +463,6 @@ public class FormatData_cv extends ListResourceBundle {
             { "roc.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "islamic.DayNames", metaValue_generic_DayNames },
             { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "islamic.DayNarrows", metaValue_generic_DayNarrows },
             { "islamic.QuarterNames", metaValue_generic_QuarterNames },
             { "islamic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "islamic.TimePatterns", metaValue_generic_TimePatterns },
@@ -566,6 +579,31 @@ public class FormatData_cv extends ListResourceBundle {
                     "",
                 }
             },
+            { "ListPatterns_standard", metaValue_ListPatterns_standard },
+            { "ListPatterns_standard-short", metaValue_ListPatterns_standard },
+            { "ListPatterns_standard-narrow",
+                new String[] {
+                    "",
+                    "",
+                    "{0}, {1}",
+                    "{0}, {1}",
+                    "",
+                }
+            },
+            { "ListPatterns_or", metaValue_ListPatterns_or },
+            { "ListPatterns_or-short", metaValue_ListPatterns_or },
+            { "ListPatterns_or-narrow", metaValue_ListPatterns_or },
+            { "ListPatterns_unit", metaValue_ListPatterns_standard },
+            { "ListPatterns_unit-short",
+                new String[] {
+                    "{0} {1}",
+                    "{0} {1}",
+                    "{0} {1}",
+                    "{0} {1}",
+                    "",
+                }
+            },
+            { "ListPatterns_unit-narrow", metaValue_ListPatterns_standard },
         };
         return data;
     }
